@@ -12,6 +12,8 @@ class PeerType(IntEnum):
     group = 3
     supergroup = 4
     user = 5
+    forum = 6
+    direct = 7
 
 
 class RoleScope(IntEnum):
